@@ -9,13 +9,15 @@ import pytest
 from _pytest.mark import MarkDecorator
 
 from _ptcsvp.plugin import BASE_DIR_KEY, Plugin
+from _ptcsvp.varname import make_name_valid
 from pytest_csv_params.dialect import CsvParamsDefaultDialect
 from pytest_csv_params.exception import (
+    CsvHeaderNameInvalid,
     CsvParamsDataFileInaccessible,
     CsvParamsDataFileInvalid,
     CsvParamsDataFileNotFound,
 )
-from pytest_csv_params.types import BaseDir, CsvDialect, DataCasts, DataFile, IdColName
+from pytest_csv_params.types import BaseDir, CsvDialect, DataCasts, DataFile, HeaderRenames, IdColName
 
 
 class TestCaseParameters(TypedDict):
@@ -53,12 +55,28 @@ def read_csv(base_dir: BaseDir, data_file: DataFile, dialect: CsvDialect) -> Lis
     return csv_lines
 
 
-def add_parametrization(
+def clean_headers(current_headers: List[str], replacing: HeaderRenames) -> List[str]:
+    """
+    Clean the CSV file headers
+    """
+    if replacing is not None:
+        for index, header in enumerate(current_headers):
+            replacement = replacing.get(header, None)
+            if replacement is not None:
+                current_headers[index] = replacement
+    current_headers = list(map(make_name_valid, current_headers))
+    if len(current_headers) != len(set(current_headers)):
+        raise CsvHeaderNameInvalid("Header names are not unique")
+    return current_headers
+
+
+def add_parametrization(  # pylint: disable=too-many-arguments
     data_file: DataFile,
     base_dir: BaseDir = None,
     id_col: IdColName = None,
     data_casts: DataCasts = None,
     dialect: CsvDialect = CsvParamsDefaultDialect,
+    header_renames: HeaderRenames = None,
 ) -> MarkDecorator:
     """
     Get data from the files and add things to the tests
@@ -78,6 +96,7 @@ def add_parametrization(
             raise CsvParamsDataFileInvalid(f"Cannot find ID column '{id_col}'") from err
     if len(headers) == 0:
         raise CsvParamsDataFileInvalid("File seems only to have IDs") from None
+    headers = clean_headers(headers, header_renames)
     data: List[TestCaseParameters] = []
     for data_line in csv_lines:
         line = list(map(str, data_line))
