@@ -2,12 +2,13 @@
 Check Version Information
 """
 import sys
+from typing import Tuple
 
 from attr.exceptions import PythonTooOldError
 from packaging.version import parse
 
 
-def check_python_version(min_version=(3, 8)):
+def check_python_version(min_version: Tuple[int, int] = (3, 8)) -> None:
     """
     Check if the current version is at least 3.8
     """
@@ -16,7 +17,7 @@ def check_python_version(min_version=(3, 8)):
         raise PythonTooOldError(f"At least Python {'.'.join(map(str, min_version))} required")
 
 
-def check_pytest_version(min_version=(7, 1)):
+def check_pytest_version(min_version: Tuple[int, int] = (7, 1)) -> None:
     """
     Check if the current version is at least 7.1
     """
