@@ -19,3 +19,9 @@ class CsvParamsDataFileInvalid(ValueError):
     """
     CSV Data is somehow invalid
     """
+
+
+class CsvHeaderNameInvalid(ValueError):
+    """
+    Invalid Header Name
+    """
