@@ -14,3 +14,6 @@ IdColName = Optional[str]
 DataFile = str
 
 CsvDialect = Type[csv.Dialect]
+
+HeaderRenamesDict = Dict[str, str]
+HeaderRenames = Optional[HeaderRenamesDict]
